/*
 * Copyright 2018 Robert C. Curtis. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *    1. Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *
 *    2. Redistributions in binary form must reproduce the above
 *       copyright notice, this list of conditions and the following
 *       disclaimer in the documentation and/or other materials
 *       provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY ROBERT C. CURTIS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL ROBERT C. CURTIS OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 *
 * The views and conclusions contained in the software and documentation
 * are those of the authors and should not be interpreted as representing
 * official policies, either expressed or implied, of Robert C. Curtis.
 */
#include <sys/time.h>
#ifdef PI
#include <time.h>
#endif
#include <stdint.h>

#ifdef __HOST_LINUX__
#include <time.h>
#endif

#ifndef I__TIMELIB_H__
	#define I__TIMELIB_H__

uint64_t time_elapsed_us(const struct timeval *start);
int time_has_elapsed_us(const struct timeval *start, uint64_t us);
float get_tstamp(void);
void epoch_to_date(uint32_t seconds, char *date, int date_size);
#if (defined(WIN32) || defined(WINDOWS) || defined(__WINDOWS__))
char *strptime(const char *s, const char *format, struct tm *tm);
#endif

#define time_has_elapsed_ms(x, y)       time_has_elapsed_us(x, y*1000)
#define time_has_elapsed_s(x, y)        time_has_elapsed_us(x, y*1000*1000)

#endif /* I__TIMELIB_H__ */
